summary refs log tree commit diff stats
path: root/src/errors.rs
diff options
context:
space:
mode:
authorSoniEx2 <endermoneymod@gmail.com>2021-02-17 23:30:06 -0300
committerSoniEx2 <endermoneymod@gmail.com>2021-02-17 23:30:06 -0300
commit6d6426743298a23a4e084684778b623b9e71882c (patch)
tree16ba2affdd57aaea7d72b3f649050f0e4f5db9ac /src/errors.rs
parent81a1d3ca72d9f28605bd22687ab20cb61a4ceb1b (diff)
Improve main documentation
Diffstat (limited to 'src/errors.rs')
-rw-r--r--src/errors.rs28
1 files changed, 17 insertions, 11 deletions
diff --git a/src/errors.rs b/src/errors.rs
index e98483f..f29d635 100644
--- a/src/errors.rs
+++ b/src/errors.rs
@@ -16,37 +16,43 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+//! <!-- TODO figure out module-level docs for this -->
+
+#[cfg(doc)]
+use crate::PatternTypes;
+
 /// These are errors that may be returned by the pattern compiler when
 /// compiling a pattern.
 ///
 /// "String" here refers to a string literal in the pattern, not the input
 /// string. The input string is referred to as "the input".
 #[derive(Debug)]
 pub enum PatternError<'a> {
     // Syntax Errors:
 
     /// The input contains an invalid string escape.
     StringEscape(usize, &'a str),
     /// The input ends in the middle of a string literal.
     StringEnd(usize, &'a str),
     /// The input contains an invalid regex escape.
     RegexEscape(usize, &'a str),
     /// The input ends in the middle of a regex literal.
     RegexEnd(usize, &'a str),
     /// The input contains characters that don't make up a token.
     Token(usize, &'a str),
 
     // Link Errors:
 
     /// The input requests a parameter that wasn't provided.
     UnknownParameter(usize, &'a str),
     /// The input requests a predicate that wasn't provided.
     UnknownPredicate(usize, &'a str),
     /// The input contains an invalid regex.
     Regex(usize, &'a str, ::regex::Error),
 }
 
-/// Error type returned by the matcher.
+/// These are errors that may be returned by the matcher when matching a
+/// pattern.
 #[derive(Clone, Debug)]
 pub enum MatchError {
     /// Returned if the pattern nests too deeply.
@@ -55,7 +61,7 @@ pub enum MatchError {
     ValidationError,
     /// Returned if the pattern attempts an unsupported operation.
     ///
-    /// In particular, if the PatternTypes doesn't support `get` or `pairs`
+    /// In particular, if the [`PatternTypes`] doesn't support `get` or `pairs`
     /// for a given value, this error will be returned. It can be treated as a
     /// ValidationError, or as a bug in the pattern, at the user's discretion.
     UnsupportedOperation,
@@ -16,37 +16,43 @@
 ///
 /// "String" here refers to a string literal in the pattern, not the input
-/// string. The input string is referred to as "the input".
+/// string. The input string is referred to as "the pattern".
 #[derive(Debug)]
 pub enum PatternError<'a> {
@@ -16,37 +16,43 @@
     // Syntax Errors:
 
-    /// The input contains an invalid string escape.
+    /// The pattern contains an invalid string escape.
     StringEscape(usize, &'a str),
@@ -16,37 +16,43 @@
     StringEscape(usize, &'a str),
-    /// The input ends in the middle of a string literal.
+    /// The pattern ends in the middle of a string literal.
     StringEnd(usize, &'a str),
@@ -16,37 +16,43 @@
     StringEnd(usize, &'a str),
-    /// The input contains an invalid regex escape.
+    /// The pattern contains an invalid regex escape.
     RegexEscape(usize, &'a str),
@@ -16,37 +16,43 @@
     RegexEscape(usize, &'a str),
-    /// The input ends in the middle of a regex literal.
+    /// The pattern ends in the middle of a regex literal.
     RegexEnd(usize, &'a str),
@@ -16,37 +16,43 @@
     RegexEnd(usize, &'a str),
-    /// The input contains characters that don't make up a token.
+    /// The pattern contains characters that don't make up a token.
     Token(usize, &'a str),
 
@@ -16,37 +16,43 @@
     // Link Errors:
 
-    /// The input requests a parameter that wasn't provided.
+    /// The pattern requests a parameter that wasn't provided.
     UnknownParameter(usize, &'a str),
@@ -16,37 +16,43 @@
     UnknownParameter(usize, &'a str),
-    /// The input requests a predicate that wasn't provided.
+    /// The pattern requests a predicate that wasn't provided.
     UnknownPredicate(usize, &'a str),
@@ -16,37 +16,43 @@
     UnknownPredicate(usize, &'a str),
-    /// The input contains an invalid regex.
+    /// The pattern contains an invalid regex.
     Regex(usize, &'a str, ::regex::Error),
 }